Int16 class

Constructors

Int16({int? data})

Properties

data ↔ int
getter/setter pair
fullType → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
md5sum → String
no setter
messageDefinition → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({int? data}) → Int16
deserialize(ByteDataReader reader) → Int16
getMessageSize() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(ByteDataWriter writer) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

$prototype ↔ Int16
getter/setter pair