Int32MultiArray class

Constructors

Int32MultiArray({MultiArrayLayout? layout, List<int>? data})

Properties

data ↔ List<int>
getter/setter pair
fullType → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
layout ↔ MultiArrayLayout
getter/setter pair
md5sum → String
no setter
messageDefinition → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

call({MultiArrayLayout? layout, List<int>? data}) → Int32MultiArray
deserialize(ByteDataReader reader) → Int32MultiArray
getMessageSize() → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize(ByteDataWriter writer) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

$prototype ↔ Int32MultiArray
getter/setter pair